#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: floors_floor_id_planned_access_point_positions_assign_access_point_positions
short_description: Resource module for Floors Floor Id Planned Access Point Positions Assign Access Point Positions
description:
  - Manage operation create of the resource Floors Floor Id Planned Access Point Positions Assign Access Point Positions.
  - Assign Planned Access Points to operations ones.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  floorId:
    description: FloorId path parameter. Floor Id.
    type: str
  payload:
    description: Floors Floor Id Planned Access Point Positions Assign Access Point Positions's payload.
    elements: dict
    suboptions:
      accessPointId:
        description: Operational Access Point Id.
        type: str
      plannedAccessPointId:
        description: Planned Access Point Id.
        type: str
    type: list
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Site Design AssignPlannedAccessPointsToOperationsOnesV2
    description: Complete reference of the AssignPlannedAccessPointsToOperationsOnesV2 API.
    link: https://developer.cisco.com/docs/dna-center/#!assign-planned-access-points-to-operations-ones-v-2
notes:
  - SDK Method used are
    site_design.SiteDesign.assign_planned_access_points_to_operations_ones_v2,
  - Paths used are
    post /dna/intent/api/v2/floors/{floorId}/plannedAccessPointPositions/assignAccessPointPositions,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.floors_floor_id_planned_access_point_positions_assign_access_point_positions:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    floorId: string
    payload:
      - accessPointId: string
        plannedAccessPointId: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "version": "string",
      "response": {
        "count": 0
      }
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: assurance_events_query_count
short_description: Resource module for Assurance Events Query Count
description:
  - Manage operation create of the resource Assurance Events Query Count. - > API to fetch the count of assurance events for
    the given complex query. Please refer to the 'API Support Documentation' section to understand which fields are supported.
    For detailed information about the usage of the API, please refer to the Open API specification document - https //github.com/cisco-en-
    programmability/catalyst-center-api-specs/blob/main/Assurance/CE_Cat_Center_Org- AssuranceEvents-1.0.0-resolved.yaml.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  deviceFamily:
    description: Device Family.
    elements: str
    type: list
  endTime:
    description: End Time.
    type: int
  filters:
    description: Assurance Events Query Count's filters.
    elements: dict
    suboptions:
      key:
        description: Key.
        type: str
      operator:
        description: Operator.
        type: str
      value:
        description: Value.
        type: str
    type: list
  headers:
    description: Additional headers.
    type: dict
  startTime:
    description: Start Time.
    type: int
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Devices CountTheNumberOfEventsWithFilters
    description: Complete reference of the CountTheNumberOfEventsWithFilters API.
    link: https://developer.cisco.com/docs/dna-center/#!count-the-number-of-events-with-filters
notes:
  - SDK Method used are
    devices.Devices.count_the_number_of_events_with_filters,
  - Paths used are
    post /dna/data/api/v1/assuranceEvents/query/count,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.assurance_events_query_count:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    deviceFamily:
      - string
    endTime: 0
    filters:
      - key: string
        operator: string
        value: string
    headers: '{{my_headers | from_json}}'
    startTime: 0
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "count": 0
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_devices_device_controllability_settings_info
short_description: Information module for Network Devices Device Controllability Settings
description:
  - Get all Network Devices Device Controllability Settings. - > Device Controllability is a system-level process on Catalyst
    Center that enforces state synchronization for some device-layer features. Its purpose is to aid in the deployment of
    required network settings that Catalyst Center needs to manage devices. Changes are made on network devices during discovery,
    when adding a device to Inventory, or when assigning a device to a site. If changes are made to any settings that are
    under the scope of this process, these changes are applied to the network devices during the Provision and Update Telemetry
    Settings operations, even if Device Controllability is disabled. The following device settings will be enabled as part
    of Device Controllability when devices are discovered. - SNMP Credentials. - NETCONF Credentials. Subsequent to discovery,
    devices will be added to Inventory. The following device settings will be enabled when devices are added to inventory.
    - Cisco TrustSec CTS Credentials. The following device settings will be enabled when devices are assigned to a site. Some
    of these settings can be defined at a site level under Design > Network Settings > Telemetry & Wireless. - Wired Endpoint
    Data Collection Enablement. - Controller Certificates. - SNMP Trap Server Definitions. - Syslog Server Definitions. -
    Application Visibility. - Application QoS Policy. - Wireless Service Assurance WSA. - Wireless Telemetry. - DTLS Ciphersuite.
    - AP Impersonation. If Device Controllability is disabled, Catalyst Center does not configure any of the preceding credentials
    or settings on devices during discovery, at runtime, or during site assignment. However, the telemetry settings and related
    configuration are pushed when the device is provisioned or when the update Telemetry Settings action is performed. Catalyst
    Center identifies and automatically corrects the following telemetry configuration issues on the device. - SWIM certificate
    issue. - IOS WLC NA certificate issue. - PKCS12 certificate issue. - IOS telemetry configuration issu.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Site Design GetDeviceControllabilitySettings
    description: Complete reference of the GetDeviceControllabilitySettings API.
    link: https://developer.cisco.com/docs/dna-center/#!get-device-controllability-settings
notes:
  - SDK Method used are
    site_design.SiteDesign.get_device_controllability_settings,
  - Paths used are
    get /dna/intent/api/v1/networkDevices/deviceControllability/settings,
"""

EXAMPLES = r"""
---
- name: Get all Network Devices Device Controllability Settings
  cisco.dnac.network_devices_device_controllability_settings_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "autocorrectTelemetryConfig": true,
        "deviceControllability": true
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: site_kpi_summaries_info
short_description: Information module for Site Kpi Summaries
description:
  - Get all Site Kpi Summaries.
  - Get Site Kpi Summaries by id.
  - Returns site analytics for all child sites of given parent site.
  - For detailed information about the usage of the API, please refer to the Open API specification document
    https //github.com/cisco-en-programmability/catalyst-center-api-specs/blob/main/Assurance/
    CE_Cat_Center_Org-SiteKpiSummaries-1.0.0-resolved.yaml.
  - Returns site analytics for the given site.
  - For detailed information about the usage of the API, please refer to the Open API specification document
    https //github.com/cisco-en-programmability/catalyst-center-api-specs/blob/main/Assurance/
    CE_Cat_Center_Org-SiteKpiSummaries-1.0.0-resolved.yaml.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  taskId:
    description:
      - >
        TaskId query parameter. Used to retrieve asynchronously processed & stored data. When this parameter is
        used, the rest of the request params will be ignored.
    type: str
  startTime:
    description:
      - >
        StartTime query parameter. Start time from which API queries the data set related to the resource. It
        must be specified in UNIX epochtime in milliseconds. Value is inclusive.
    type: float
  endTime:
    description:
      - >
        EndTime query parameter. End time to which API queries the data set related to the resource. It must be
        specified in UNIX epochtime in milliseconds. Value is inclusive.
    type: float
  siteHierarchy:
    description:
      - >
        SiteHierarchy query parameter. The full hierarchical breakdown of the site tree starting from Global
        site name and ending with the specific site name. The Root site is named "Global" (Ex.
        `Global/AreaName/BuildingName/FloorName`) This field supports wildcard asterisk (`*`) character search
        support. E.g. `*/San*, */San, /San*` Examples `?siteHierarchy=Global/AreaName/BuildingName/FloorName`
        (single siteHierarchy requested) `?siteHierarchy=Global/AreaName/BuildingName/FloorName&siteHierarchy=Gl
        obal/AreaName2/BuildingName2/FloorName2` (multiple siteHierarchies requested).
    type: str
  siteHierarchyId:
    description:
      - >
        SiteHierarchyId query parameter. The full hierarchy breakdown of the site tree in id form starting from
        Global site UUID and ending with the specific site UUID. (Ex.
        `globalUuid/areaUuid/buildingUuid/floorUuid`) This field supports wildcard asterisk (`*`) character
        search support. E.g. `*uuid*, *uuid, uuid*` Examples
        `?siteHierarchyId=globalUuid/areaUuid/buildingUuid/floorUuid `(single siteHierarchyId requested) `?siteH
        ierarchyId=globalUuid/areaUuid/buildingUuid/floorUuid&siteHierarchyId=globalUuid/areaUuid2/buildingUuid2
        /floorUuid2` (multiple siteHierarchyIds requested).
    type: str
  siteId:
    description:
      - >
        SiteId query parameter. The UUID of the site. (Ex. `flooruuid`) Examples `?siteId=id1` (single id
        requested) `?siteId=id1&siteId=id2&siteId=id3` (multiple ids requested).
    type: str
  siteType:
    description:
      - >
        SiteType query parameter. The type of the site. A site can be an area, building, or floor. Default when
        not provided will be `floor,building,area` Examples `?siteType=area` (single siteType requested)
        `?siteType=area&siteType=building&siteType=floor` (multiple siteTypes requested).
    type: str
  ssid:
    description:
      - >
        Ssid query parameter. SSID is the name of wireless network to which client connects to. It is also
        referred to as WLAN ID - Wireless Local Area Network Identifier. Examples `ssid=Alpha` (single ssid
        requested) `ssid=Alpha&ssid=Guest` (multiple ssid requested).
    type: str
  band:
    description:
      - >
        Band query parameter. WiFi frequency band that client or Access Point operates. Band value is
        represented in Giga Hertz - GHz Examples `band=5` (single band requested) `band=2.4&band=6` (multiple
        band requested).
    type: str
  failureCategory:
    description:
      - >
        FailureCategory query parameter. Category of failure when a client fails to meet the threshold. Examples
        `failureCategory=AUTH` (single failure category requested) `failureCategory=AUTH&failureCategory=DHCP`
        (multiple failure categories requested).
    type: str
  failureReason:
    description:
      - >
        FailureReason query parameter. Reason for failure when a client fails to meet the threshold. Examples
        `failureReason=MOBILITY_FAILURE` (single ssid requested)
        `failureReason=REASON_IPLEARN_CONNECT_TIMEOUT&failureReason=ST_EAP_TIMEOUT` (multiple ssid requested).
    type: str
  view:
    description:
      - >
        View query parameter. <p>The name of the View. Each view represents a specific data set. Please refer to
        the <code>SiteAnalyticsView</code> Model for supported views. View is predefined set of attributes
        supported by the API. Only the attributes related to the given view will be part of the API response
        along with default attributes. If multiple views are provided, then response will contain attributes
        from all those views. If no views are specified, all attributes will be
        returned.</p><table><thead><tr><th>View Name</th><th>Included
        Attributes</th></tr></thead><tbody><tr><td><code>coverage</code></td><td>coverageAverage,
        coverageSuccessPercentage, coverageSuccessCount, coverageTotalCount, coverageFailureCount,
        coverageClientCount, coverageImpactedEntities, coverageFailureImpactedEntities, coverageFailureMetrics</
        td></tr><tr><td><code>onboardingAttempts</code></td><td>onboardingAttemptsSuccessPercentage,
        onboardingAttemptsSuccessCount, onboardingAttemptsTotalCount, onboardingAttemptsFailureCount,
        onboardingAttemptsClientCount, onboardingAttemptsImpactedEntities,
        onboardingAttemptsFailureImpactedEntities, onboardingAttemptsFailureMetrics</td></tr><tr><td><code>onboa
        rdingDuration</code></td><td>onboardingDurationAverage, onboardingDurationSuccessPercentage,
        onboardingDurationSuccessCount, onboardingDurationTotalCount, onboardingDurationFailureCount,
        onboardingDurationClientCount, onboardingDurationImpactedEntities,
        onboardingDurationFailureImpactedEntities, onboardingDurationFailureMetrics</td></tr><tr><td><code>roami
        ngAttempts</code></td><td>roamingAttemptsSuccessPercentage, roamingAttemptsSuccessCount,
        roamingAttemptsTotalCount, roamingAttemptsFailureCount, roamingAttemptsClientCount,
        roamingAttemptsImpactedEntities, roamingAttemptsFailureImpactedEntities, roamingAttemptsFailureMetrics</
        td></tr><tr><td><code>roamingDuration</code></td><td>roamingDurationAverage,
        roamingDurationSuccessPercentage, roamingDurationSuccessCount, roamingDurationTotalCount,
        roamingDurationFailureCount, roamingDurationClientCount, roamingDurationImpactedEntities,
        roamingDurationFailureImpactedEntities, roamingDurationFailureMetrics</td></tr><tr><td><code>connectionS
        peed</code></td><td>connectionSpeedAverage, connectionSpeedSuccessPercentage,
        connectionSpeedSuccessCount, connectionSpeedTotalCount, connectionSpeedFailureCount,
        connectionSpeedClientCount, connectionSpeedImpactedEntities, connectionSpeedFailureImpactedEntities,
        connectionSpeedFailureMetrics</td></tr></tbody></table><p>Examples <code>view=connectionSpeed</code>
        (single view requested) <code>view=roamingDuration&amp;view=roamingAttempts</code> (multiple views
        requested) </p>.
    type: str
  attribute:
    description:
      - >
        Attribute query parameter. List of attributes related to site analytics. If these are provided, then
        only those attributes will be part of response along with the default attributes. Examples
        `attribute=coverageAverage` (single attribute requested)
        `attribute=coverageFailureMetrics&attribute=coverageTotalCount` (multiple attributes requested).
    type: str
  limit:
    description:
      - Limit query parameter. Maximum number of records to return.
    type: int
  offset:
    description:
      - >
        Offset query parameter. Specifies the starting point within all records returned by the API. It's one
        based offset. The starting value is 1.
    type: int
  sortBy:
    description:
      - SortBy query parameter. Field name on which sorting needs to be done.
    type: str
  order:
    description:
      - Order query parameter. The sort order of the field ascending or descending.
    type: str
  id:
    description:
      - Id path parameter. The Site UUID.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Sites GetSiteAnalyticsForOneSite
    description: Complete reference of the GetSiteAnalyticsForOneSite API.
    link: https://developer.cisco.com/docs/dna-center/#!get-site-analytics-for-one-site
  - name: Cisco DNA Center documentation for Sites GetSiteAnalyticsForTheChildSitesOfGivenParentSiteAndOtherQueryParameters
    description: Complete reference of the GetSiteAnalyticsForTheChildSitesOfGivenParentSiteAndOtherQueryParameters API.
    link: https://developer.cisco.com/docs/dna-center/#!get-site-analytics-for-the-child-sites-of-given-parent-site-and-other-query-parameters
notes:
  - SDK Method used are
    sites.Sites.get_site_analytics_for_one_site,
    sites.Sites.get_site_analytics_for_the_child_sites_of_given_parent_site_and_other_query_parameters,
  - Paths used are
    get /dna/data/api/v1/siteKpiSummaries,
    get /dna/data/api/v1/siteKpiSummaries/{id},
"""

EXAMPLES = r"""
---
- name: Get all Site Kpi Summaries
  cisco.dnac.site_kpi_summaries_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    taskId: string
    startTime: 0
    endTime: 0
    siteHierarchy: string
    siteHierarchyId: string
    siteId: string
    siteType: string
    ssid: string
    band: string
    failureCategory: string
    failureReason: string
    view: string
    attribute: string
    limit: 0
    offset: 0
    sortBy: string
    order: string
  register: result
- name: Get Site Kpi Summaries by id
  cisco.dnac.site_kpi_summaries_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    taskId: string
    startTime: 0
    endTime: 0
    ssid: string
    band: string
    failureCategory: string
    failureReason: string
    view: string
    attribute: string
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "id": "string",
        "siteId": "string",
        "siteHierarchyId": "string",
        "siteHierarchy": "string",
        "siteType": "string",
        "apCount": 0,
        "coverageAverage": 0,
        "coverageSuccessPercentage": 0,
        "coverageSuccessCount": 0,
        "coverageTotalCount": 0,
        "coverageFailureCount": 0,
        "coverageClientCount": 0,
        "coverageImpactedEntities": {
          "buildingCount": 0,
          "floorCount": 0,
          "sitesCount": 0,
          "apCount": 0
        },
        "coverageFailureImpactedEntities": {
          "buildingCount": 0,
          "floorCount": 0,
          "sitesCount": 0,
          "apCount": 0
        },
        "coverageFailureMetrics": {
          "failureApCount": 0,
          "failureClientCount": 0,
          "failurePercentage": 0
        },
        "onboardingAttemptsSuccessPercentage": 0,
        "onboardingAttemptsSuccessCount": 0,
        "onboardingAttemptsTotalCount": 0,
        "onboardingAttemptsFailureCount": 0,
        "onboardingAttemptsClientCount": 0,
        "onboardingAttemptsImpactedEntities": {
          "buildingCount": 0,
          "floorCount": 0,
          "sitesCount": 0,
          "apCount": 0
        },
        "onboardingAttemptsFailureImpactedEntities": {
          "buildingCount": 0,
          "floorCount": 0,
          "sitesCount": 0,
          "apCount": 0
        },
        "onboardingAttemptsFailureMetrics": {
          "failureApCount": 0,
          "failureClientCount": 0,
          "failurePercentage": 0
        },
        "onboardingDurationAverage": 0,
        "onboardingDurationSuccessPercentage": 0,
        "onboardingDurationSuccessCount": 0,
        "onboardingDurationTotalCount": 0,
        "onboardingDurationFailureCount": 0,
        "onboardingDurationClientCount": 0,
        "onboardingDurationImpactedEntities": {
          "buildingCount": 0,
          "floorCount": 0,
          "sitesCount": 0,
          "apCount": 0
        },
        "onboardingDurationFailureImpactedEntities": {
          "buildingCount": 0,
          "floorCount": 0,
          "sitesCount": 0,
          "apCount": 0
        },
        "onboardingDurationFailureMetrics": {
          "failureApCount": 0,
          "failureClientCount": 0,
          "failurePercentage": 0
        },
        "roamingAttemptsSuccessPercentage": 0,
        "roamingAttemptsSuccessCount": 0,
        "roamingAttemptsTotalCount": 0,
        "roamingAttemptsFailureCount": 0,
        "roamingAttemptsClientCount": 0,
        "roamingAttemptsImpactedEntities": {
          "buildingCount": 0,
          "floorCount": 0,
          "sitesCount": 0,
          "apCount": 0
        },
        "roamingAttemptsFailureImpactedEntities": {
          "buildingCount": 0,
          "floorCount": 0,
          "sitesCount": 0,
          "apCount": 0
        },
        "roamingAttemptsFailureMetrics": {
          "failureApCount": 0,
          "failureClientCount": 0,
          "failurePercentage": 0
        },
        "roamingDurationAverage": 0,
        "roamingDurationSuccessPercentage": 0,
        "roamingDurationSuccessCount": 0,
        "roamingDurationTotalCount": 0,
        "roamingDurationFailureCount": 0,
        "roamingDurationClientCount": 0,
        "roamingDurationImpactedEntities": {
          "buildingCount": 0,
          "floorCount": 0,
          "sitesCount": 0,
          "apCount": 0
        },
        "roamingDurationFailureImpactedEntities": {
          "buildingCount": 0,
          "floorCount": 0,
          "sitesCount": 0,
          "apCount": 0
        },
        "roamingDurationFailureMetrics": {
          "failureApCount": 0,
          "failureClientCount": 0,
          "failurePercentage": 0
        },
        "connectionSpeedAverage": 0,
        "connectionSpeedSuccessPercentage": 0,
        "connectionSpeedSuccessCount": 0,
        "connectionSpeedTotalCount": 0,
        "connectionSpeedFailureCount": 0,
        "connectionSpeedClientCount": 0,
        "connectionSpeedImpactedEntities": {
          "buildingCount": 0,
          "floorCount": 0,
          "sitesCount": 0,
          "apCount": 0
        },
        "connectionSpeedFailureImpactedEntities": {
          "buildingCount": 0,
          "floorCount": 0,
          "sitesCount": 0,
          "apCount": 0
        },
        "connectionSpeedFailureMetrics": {
          "failureApCount": 0,
          "failureClientCount": 0,
          "failurePercentage": 0
        }
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: wireless_profiles
short_description: Resource module for Wireless Profiles
description:
  - Manage operations create, update and delete of the resource Wireless Profiles.
  - This API allows the user to create a Wireless Network Profile.
  - This API allows the user to delete Wireless Network Profile by ID. - > This API allows the user to update a Wireless Network
    Profile by ID. Note that, when performing a PUT operation on a wireless network profile, it is essential to provide a
    complete payload. This is because the wireless network profile is tightly integrated with other network design entities.
    Consequently, all fields must be included—not just the fields to be updated. Any missing fields will be set to their default
    or null values. To ensure all fields are accurately populated, consider using the GET operation to retrieve the current
    resource data before proceeding with the PUT operation.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  additionalInterfaces:
    description: These additional interfaces will be configured on the device as independent interfaces in addition to the
      interfaces mapped to SSIDs. Max Limit 4094.
    elements: str
    type: list
  apZones:
    description: Wireless Profiles's apZones.
    elements: dict
    suboptions:
      apZoneName:
        description: AP Zone Name.
        type: str
      rfProfileName:
        description: RF Profile Name.
        type: str
      ssids:
        description: Ssids part of apZone.
        elements: str
        type: list
    type: list
  featureTemplates:
    description: Wireless Profiles's featureTemplates.
    elements: dict
    suboptions:
      id:
        description: Feature Template UUID.
        type: str
      ssids:
        description: List of SSIDs.
        elements: str
        type: list
    type: list
  id:
    description: Id path parameter. Wireless Profile Id.
    type: str
  ssidDetails:
    description: Wireless Profiles's ssidDetails.
    elements: dict
    suboptions:
      anchorGroupName:
        description: Anchor Group Name.
        type: str
      dot11beProfileId:
        description: 802.11be Profile ID. Applicable to IOS controllers with version 17.15 and higher.
        type: str
      enableFabric:
        description: true if fabric is enabled, else False. Flex and fabric cannot be enabled simultaneously and a profile
          can only contain either flex SSIDs or fabric SSIDs and not both at the same time.
        type: bool
      flexConnect:
        description: Wireless Profiles's flexConnect.
        suboptions:
          enableFlexConnect:
            description: true if flex connect is enabled, else False. Flex and fabric cannot be enabled simultaneously and
              a profile can only contain either flex SSIDs or fabric SSIDs and not both at the same time.
            type: bool
          localToVlan:
            description: Local to VLAN ID.
            type: int
        type: dict
      interfaceName:
        description: Interface Name.
        type: str
      policyProfileName:
        description: "Policy Profile Name. If 'policyProfileName' is not provided, the value of 'wlanProfileName' will be
          assigned to it. If 'profileName' is also not provided, an autogenerated name will be used. Autogenerated name is
          generated by appending 'ssidName' field's value with '_profile' (Example If 'ssidName' = 'ExampleSsid', then autogenerated
          name will be 'ExampleSsid_profile')."
        type: str
      ssidName:
        description: SSID Name.
        type: str
      vlanGroupName:
        description: VLAN Group Name.
        type: str
      wlanProfileName:
        description: WLAN Profile Name, if not passed autogenerated profile name will be assigned.
        type: str
    type: list
  wirelessProfileName:
    description: Wireless Network Profile Name.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Wireless CreateWirelessProfileConnectivity
    description: Complete reference of the CreateWirelessProfileConnectivity API.
    link: https://developer.cisco.com/docs/dna-center/#!create-wireless-profile-connectivity
  - name: Cisco DNA Center documentation for Wireless DeleteWirelessProfileConnectivity
    description: Complete reference of the DeleteWirelessProfileConnectivity API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-wireless-profile-connectivity
  - name: Cisco DNA Center documentation for Wireless UpdateWirelessProfileConnectivity
    description: Complete reference of the UpdateWirelessProfileConnectivity API.
    link: https://developer.cisco.com/docs/dna-center/#!update-wireless-profile-connectivity
notes:
  - SDK Method used are
    wireless.Wireless.create_wireless_profile_connectivity,
    wireless.Wireless.delete_wireless_profile_connectivity,
    wireless.Wireless.update_wireless_profile_connectivity,
  - Paths used are
    post /dna/intent/api/v1/wirelessProfiles,
    delete /dna/intent/api/v1/wirelessProfiles/{id},
    put /dna/intent/api/v1/wirelessProfiles/{id},
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.wireless_profiles:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    additionalInterfaces:
      - string
    apZones:
      - apZoneName: string
        rfProfileName: string
        ssids:
          - string
    featureTemplates:
      - id: string
        ssids:
          - string
    ssidDetails:
      - anchorGroupName: string
        dot11beProfileId: string
        enableFabric: true
        flexConnect:
          enableFlexConnect: true
          localToVlan: 0
        interfaceName: string
        policyProfileName: string
        ssidName: string
        vlanGroupName: string
        wlanProfileName: string
    wirelessProfileName: string
- name: Delete by id
  cisco.dnac.wireless_profiles:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    id: string
- name: Update by id
  cisco.dnac.wireless_profiles:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    additionalInterfaces:
      - string
    apZones:
      - apZoneName: string
        rfProfileName: string
        ssids:
          - string
    featureTemplates:
      - id: string
        ssids:
          - string
    id: string
    ssidDetails:
      - anchorGroupName: string
        dot11beProfileId: string
        enableFabric: true
        flexConnect:
          enableFlexConnect: true
          localToVlan: 0
        interfaceName: string
        policyProfileName: string
        ssidName: string
        vlanGroupName: string
        wlanProfileName: string
    wirelessProfileName: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
module: networks_sm_devices_performance_history_info
short_description: Information module for networks _sm _devices _performancehistory
description:
  - Information module for Networks Sm Devices Performancehistory Info.
  - Get all networks _sm _devices _performancehistory.
  - Return historical records of various Systems Manager client metrics for desktop
    devices.
version_added: '1.0.0'
extends_documentation_fragment:
  - cisco.meraki.module_info
  - cisco.meraki.module_info_pagination
author: Francisco Munoz (@fmunoz)
options:
  headers:
    description: Additional headers.
    type: dict
  networkId:
    description:
      - Information module for Networks Sm Devices Performancehistory Info.
      - NetworkId path parameter. Network ID.
    type: str
  deviceId:
    description:
      - Information module for Networks Sm Devices Performancehistory Info.
      - DeviceId path parameter. Device ID.
    type: str
  perPage:
    description:
      - Information module for Networks Sm Devices Performancehistory Info.
      - PerPage query parameter. The number of entries per page returned. Acceptable
        range is 3 - 1000. Default is 1000.
    type: int
  startingAfter:
    description:
      - Information module for Networks Sm Devices Performancehistory Info.
      - >
        StartingAfter query parameter. A token used by the server to indicate the
        start of the page. Often this is a timestamp or an ID but it is not limited
        to those. This parameter should not be defined by client applications. The
        link for the first, last, prev, or next page in the HTTP Link header should
        define it.
    type: str
  endingBefore:
    description:
      - Information module for Networks Sm Devices Performancehistory Info.
      - >
        EndingBefore query parameter. A token used by the server to indicate the end
        of the page. Often this is a timestamp or an ID but it is not limited to those.
        This parameter should not be defined by client applications. The link for
        the first, last, prev, or next page in the HTTP Link header should define
        it.
    type: str
requirements:
  - meraki >= 2.4.9
  - python >= 3.5
seealso:
  - name: Cisco Meraki documentation for sm getNetworkSmDevicePerformanceHistory
    description: Complete reference of the getNetworkSmDevicePerformanceHistory API.
    link: https://developer.cisco.com/meraki/api-v1/#!get-network-sm-device-performance-history
notes:
  - SDK Method used are
    sm.Sm.get_network_sm_device_performance_history,
  - Paths used are
    get /networks/{networkId}/sm/devices/{deviceId}/performanceHistory,
"""

EXAMPLES = r"""
- name: Get all networks _sm _devices _performancehistory
  cisco.meraki.networks_sm_devices_performance_history_info:
    meraki_api_key: "{{ meraki_api_key }}"
    meraki_base_url: "{{ meraki_base_url }}"
    meraki_single_request_timeout: "{{ meraki_single_request_timeout }}"
    meraki_certificate_path: "{{ meraki_certificate_path }}"
    meraki_requests_proxy: "{{ meraki_requests_proxy }}"
    meraki_wait_on_rate_limit: "{{ meraki_wait_on_rate_limit }}"
    meraki_nginx_429_retry_wait_time: "{{ meraki_nginx_429_retry_wait_time }}"
    meraki_action_batch_retry_wait_time: "{{ meraki_action_batch_retry_wait_time }}"
    meraki_retry_4xx_error: "{{ meraki_retry_4xx_error }}"
    meraki_retry_4xx_error_wait_time: "{{ meraki_retry_4xx_error_wait_time }}"
    meraki_maximum_retries: "{{ meraki_maximum_retries }}"
    meraki_output_log: "{{ meraki_output_log }}"
    meraki_log_file_prefix: "{{ meraki_log_file_prefix }}"
    meraki_log_path: "{{ meraki_log_path }}"
    meraki_print_console: "{{ meraki_print_console }}"
    meraki_suppress_logging: "{{ meraki_suppress_logging }}"
    meraki_simulate: "{{ meraki_simulate }}"
    meraki_be_geo_id: "{{ meraki_be_geo_id }}"
    meraki_caller: "{{ meraki_caller }}"
    meraki_use_iterator_for_get_pages: "{{ meraki_use_iterator_for_get_pages }}"
    meraki_inherit_logging_config: "{{ meraki_inherit_logging_config }}"
    perPage: 0
    startingAfter: string
    endingBefore: string
    networkId: string
    deviceId: string
    total_pages: -1
    direction: next
  register: result
"""
RETURN = r"""
meraki_response:
  description: A dictionary or list with the response returned by the Cisco Meraki Python SDK
  returned: always
  type: list
  elements: dict
  sample: >
    [
      {
        "cpuPercentUsed": 0,
        "memFree": 0,
        "memWired": 0,
        "memActive": 0,
        "memInactive": 0,
        "networkSent": 0,
        "networkReceived": 0,
        "swapUsed": 0,
        "diskUsage": {
          "c": {
            "used": 0,
            "space": 0
          }
        },
        "ts": "string"
      }
    ]
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: wireless_settings_power_profiles
short_description: Resource module for Wireless Settings Power Profiles
description:
  - Manage operations create, update and delete of the resource Wireless Settings Power Profiles.
  - This API allows the user to create a custom Power Profile.
  - This API allows the user to delete an Power Profile by specifying the Power Profile ID.
  - This API allows the user to update a custom power Profile.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  description:
    description: Description of the Power Profile. Max allowed characters is 128.
    type: str
  id:
    description: Id path parameter. Power Profile ID.
    type: str
  profileName:
    description: Name of the Power Profile. Max allowed characters is 128.
    type: str
  rules:
    description: Wireless Settings Power Profiles's rules.
    elements: dict
    suboptions:
      interfaceId:
        description: Interface Id for the rule.
        type: str
      interfaceType:
        description: Interface Type for the rule.
        type: str
      parameterType:
        description: Parameter Type for the rule.
        type: str
      parameterValue:
        description: Parameter Value for the rule.
        type: str
    type: list
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Wireless CreatePowerProfile
    description: Complete reference of the CreatePowerProfile API.
    link: https://developer.cisco.com/docs/dna-center/#!create-power-profile
  - name: Cisco DNA Center documentation for Wireless DeletePowerProfileByID
    description: Complete reference of the DeletePowerProfileByID API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-power-profile-by-id
  - name: Cisco DNA Center documentation for Wireless UpdatePowerProfileByID
    description: Complete reference of the UpdatePowerProfileByID API.
    link: https://developer.cisco.com/docs/dna-center/#!update-power-profile-by-id
notes:
  - SDK Method used are
    wireless.Wireless.create_power_profile,
    wireless.Wireless.delete_power_profile_by_id,
    wireless.Wireless.update_power_profile_by_id,
  - Paths used are
    post /dna/intent/api/v1/wirelessSettings/powerProfiles,
    delete /dna/intent/api/v1/wirelessSettings/powerProfiles/{id},
    put /dna/intent/api/v1/wirelessSettings/powerProfiles/{id},
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.wireless_settings_power_profiles:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    description: string
    profileName: string
    rules:
      - interfaceId: string
        interfaceType: string
        parameterType: string
        parameterValue: string
- name: Delete by id
  cisco.dnac.wireless_settings_power_profiles:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    id: string
- name: Update by id
  cisco.dnac.wireless_settings_power_profiles:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    description: string
    id: string
    profileName: string
    rules:
      - interfaceID: string
        interfaceType: string
        parameterType: string
        parameterValue: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: floors_floor_id_access_point_positions_count_info
short_description: Information module for Floors Floor Id Access Point Positions Count
description:
  - Get all Floors Floor Id Access Point Positions Count.
  - Retrieve Access Points positions count assigned for a specific floor.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  floorId:
    description:
      - FloorId path parameter. Floor Id.
    type: str
  name:
    description:
      - Name query parameter. Access Point name.
    type: str
  macAddress:
    description:
      - MacAddress query parameter. Access Point mac address.
    type: str
  type:
    description:
      - Type query parameter. Access Point type.
    type: str
  model:
    description:
      - Model query parameter. Access Point model.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Site Design GetAccessPointsPositionsCountV2
    description: Complete reference of the GetAccessPointsPositionsCountV2 API.
    link: https://developer.cisco.com/docs/dna-center/#!get-access-points-positions-count-v-2
notes:
  - SDK Method used are
    site_design.SiteDesign.get_access_points_positions_count_v2,
  - Paths used are
    get /dna/intent/api/v2/floors/{floorId}/accessPointPositions/count,
"""

EXAMPLES = r"""
---
- name: Get all Floors Floor Id Access Point Positions Count
  cisco.dnac.floors_floor_id_access_point_positions_count_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    name: string
    macAddress: string
    type: string
    model: string
    floorId: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "count": 0
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: icap_settings_configuration_models_preview_activity_id_network_devices_network_device_id_config
short_description: Resource module for Icap Settings Configuration Models Preview Activity Id Network Devices Network Device
  Id Config
description:
  - Manage operation create of the resource Icap Settings Configuration Models Preview Activity Id Network Devices Network
    Device Id Config. - > Generates the device's CLIs of the ICAP intent for preview and approve prior to deploying the ICAP
    configuration intent to the device. After deploying the configuration intent, generating intent CLIs will not be available
    for preview. For detailed information about the usage of the API, please refer to the Open API specification document
    - https //github.com/cisco-en-programmability/catalyst-center-api- specs/blob/main/Assurance/CE_Cat_Center_Org-ICAP_APIs-1.0.0-resolved.yaml.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  networkDeviceId:
    description: NetworkDeviceId path parameter. Device id from intent/api/v1/network-device.
    type: str
  previewActivityId:
    description: PreviewActivityId path parameter. Activity from the POST /deviceConfigugrationModels task response.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Sensors GeneratesTheDevicesCLIsOfTheICAPConfigurationIntent
    description: Complete reference of the GeneratesTheDevicesCLIsOfTheICAPConfigurationIntent API.
    link: https://developer.cisco.com/docs/dna-center/#!generates-the-devices-cl-is-of-the-icap-configuration-intent
notes:
  - SDK Method used are
    sensors.Sensors.generates_the_devices_clis_of_the_i_cap_configuration_intent,
  - Paths used are
    post /dna/intent/api/v1/icapSettings/configurationModels/{previewActivityId}/networkDevices/{networkDeviceId}/config,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.icap_settings_configuration_models_preview_activity_id_network_devices_network_device_id_config:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    networkDeviceId: string
    previewActivityId: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_device_maintenance_schedules
short_description: Resource module for Network Device Maintenance Schedules
description:
  - Manage operations create, update and delete of the resource Network Device Maintenance Schedules. - > API to create maintenance
    schedule for network devices. The state of network device can be queried using API `GET /dna/intent/api/v1/networkDevices`.
    The `managementState` attribute of the network device will be updated to `UNDER_MAINTENANCE` when the maintenance window
    starts. - > API to delete maintenance schedule by id. Deletion is allowed if the maintenance window is in the `UPCOMING`,
    `COMPLETED`, or `FAILED` state. Deletion of maintenance schedule is not allowed if the maintenance window is currently
    `IN_PROGRESS`. To delete the maintenance schedule while it is `IN_PROGRESS`, first exit the current maintenance window
    using `PUT /dna/intent/api/v1/networkDeviceMaintenanceSchedules/{id}` API, and then proceed to delete the maintenance
    schedule.
  - API to update the maintenance schedule for the network devices.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  description:
    description: A brief narrative describing the maintenance schedule.
    type: str
  id:
    description: Id path parameter. Unique identifier for the maintenance schedule.
    type: str
  maintenanceSchedule:
    description: Network Device Maintenance Schedules's maintenanceSchedule.
    suboptions:
      endTime:
        description: End time indicates the ending of the maintenance window in Unix epoch time in milliseconds.
        type: float
      recurrence:
        description: Network Device Maintenance Schedules's recurrence.
        suboptions:
          interval:
            description: Interval for recurrence in days. The interval must be longer than the duration of the schedules.
              The maximum allowed interval is 365 days.
            type: int
          recurrenceEndTime:
            description: The end date for the recurrence in Unix epoch time in milliseconds. Recurrence end time should be
              greater than maintenance end date/time.
            type: float
        type: dict
      startTime:
        description: Start time indicates the beginning of the maintenance window in Unix epoch time in milliseconds.
        type: float
    type: dict
  networkDeviceIds:
    description: List of network device ids. This field is applicable only during creation of schedules; for updates, it is
      read-only.
    elements: str
    type: list
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Devices CreateMaintenanceScheduleForNetworkDevices
    description: Complete reference of the CreateMaintenanceScheduleForNetworkDevices API.
    link: https://developer.cisco.com/docs/dna-center/#!create-maintenance-schedule-for-network-devices
  - name: Cisco DNA Center documentation for Devices DeleteMaintenanceSchedule
    description: Complete reference of the DeleteMaintenanceSchedule API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-maintenance-schedule
  - name: Cisco DNA Center documentation for Devices UpdatesTheMaintenanceScheduleInformation
    description: Complete reference of the UpdatesTheMaintenanceScheduleInformation API.
    link: https://developer.cisco.com/docs/dna-center/#!updates-the-maintenance-schedule-information
notes:
  - SDK Method used are
    devices.Devices.create_maintenance_schedule_for_network_devices,
    devices.Devices.delete_maintenance_schedule,
    devices.Devices.updates_the_maintenance_schedule_information,
  - Paths used are
    post /dna/intent/api/v1/networkDeviceMaintenanceSchedules,
    delete /dna/intent/api/v1/networkDeviceMaintenanceSchedules/{id},
    put /dna/intent/api/v1/networkDeviceMaintenanceSchedules/{id},
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.network_device_maintenance_schedules:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    description: string
    maintenanceSchedule:
      endTime: 0
      recurrence:
        interval: 0
        recurrenceEndTime: 0
      startTime: 0
    networkDeviceIds:
      - string
- name: Delete by id
  cisco.dnac.network_device_maintenance_schedules:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    id: string
- name: Update by id
  cisco.dnac.network_device_maintenance_schedules:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    description: string
    id: string
    maintenanceSchedule:
      endTime: 0
      recurrence:
        interval: 0
        recurrenceEndTime: 0
      startTime: 0
    networkDeviceIds:
      - string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
#
# Copyright (c) 2018
# Gustavo Muniz do Carmo <gustavo@esign.com.br>
# Zim Kalinowski <zikalino@microsoft.com>
#
# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)

from __future__ import absolute_import, division, print_function
__metaclass__ = type


DOCUMENTATION = '''
---
module: azure_rm_virtualmachine_info

version_added: "0.1.2"

short_description: Get virtual machine facts

description:
    - Get facts for one or all virtual machines in a resource group.

options:
    resource_group:
        description:
            - Name of the resource group containing the virtual machines (required when filtering by vm name).
        type: str
    name:
        description:
            - Name of the virtual machine.
        type: str
    tags:
        description:
            - Limit results by providing a list of tags. Format tags as 'key' or 'key:value'.
        type: list
        elements: str

extends_documentation_fragment:
    - azure.azcollection.azure

author:
    - Gustavo Muniz do Carmo (@gustavomcarmo)
    - Zim Kalinowski (@zikalino)

'''

EXAMPLES = '''
- name: Get facts for all virtual machines of a resource group
  azure_rm_virtualmachine_info:
    resource_group: myResourceGroup

- name: Get facts by name
  azure_rm_virtualmachine_info:
    resource_group: myResourceGroup
    name: myVm

- name: Get facts by tags
  azure_rm_virtualmachine_info:
    resource_group: myResourceGroup
    tags:
      - testing
      - foo:bar
'''

RETURN = '''
vms:
    description:
        - List of virtual machines.
    returned: always
    type: complex
    contains:
        additional_capabilities:
            description:
                - Enables or disables a capability on the virtual machine.
            type: dict
            returned: always
            sample: {ultra_ssd_enabled: False}
        admin_username:
            description:
                - Administrator user name.
            returned: always
            type: str
            sample: admin
        boot_diagnostics:
            description:
                - Information about the boot diagnostics settings.
            returned: always
            type: complex
            contains:
                enabled:
                    description:
                        - Indicates if boot diagnostics are enabled.
                    returned: always
                    type: bool
                    sample: true
                storage_uri:
                    description:
                        - Indicates the storage account used by boot diagnostics.
                    returned: always
                    type: str
                    sample: https://mystorageaccountname.blob.core.windows.net/
                console_screenshot_uri:
                    description:
                        - Contains a URI to grab a console screenshot.
                        - Only present if enabled.
                    returned: always
                    type: str
                    sample: https://mystorageaccountname.blob.core.windows.net/bootdiagnostics-myvm01-a4db09a6-ab7f-4d80-9da8-fbceaef9288a/
                            myVm.a4db09a6-ab7f-4d80-9da8-fbceaef9288a.screenshot.bmp
                serial_console_log_uri:
                    description:
                        - Contains a URI to grab the serial console log.
                        - Only present if enabled.
                    returned: always
                    type: str
                    sample: https://mystorageaccountname.blob.core.windows.net/bootdiagnostics-myvm01-a4db09a6-ab7f-4d80-9da8-fbceaef9288a/
                            myVm.a4db09a6-ab7f-4d80-9da8-fbceaef9288a.serialconsole.log
        data_disks:
            description:
                - List of attached data disks.
            returned: always
            type: complex
            contains:
                caching:
                    description:
                        - Type of data disk caching.
                    returned: always
                    type: str
                    sample: ReadOnly
                disk_size_gb:
                    description:
                        - The initial disk size in GB for blank data disks.
                    returned: always
                    type: int
                    sample: 64
                lun:
                    description:
                        - The logical unit number for data disk.
                    returned: always
                    type: int
                    sample: 0
                managed_disk_type:
                    description:
                        - Managed data disk type.
                    returned: always
                    type: str
                    sample: Standard_LRS
                managed_disk_id:
                    description:
                        - Managed data disk ID.
                    returned: always
                    type: str
                    sample: /subscriptions/xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx/resourceGroups/myResourceGroup/Microsoft.Compute/disks/diskName
                write_accelerator_enabled:
                    description:
                        - Specifies whether writeAccelerator should be enabled or disabled on the disk.
                    type: bool
                    returned: always
                    sample: False
        user_data:
            description:
                - UserData for the VM, which must be base-64 encoded.
            type: str
            returned: always
            sample: None
        id:
            description:
                - Resource ID.
            returned: always
            type: str
            sample: /subscriptions/xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx/resourceGroups/myResourceGroup/providers/Microsoft.Compute/virtualMachines/myVm
        image:
            description:
                - Image specification.
            returned: always
            type: complex
            contains:
                offer:
                    description:
                        - The offer of the platform image or marketplace image used to create the virtual machine.
                    type: str
                    returned: when created from marketplace image
                    sample: RHEL
                publisher:
                    description:
                        - Publisher name.
                    type: str
                    returned: when created from marketplace image
                    sample: RedHat
                sku:
                    description:
                        - SKU name.
                    type: str
                    returned: when created from marketplace image
                    sample: 7-RAW
                version:
                    description:
                        - Image version.
                    type: str
                    returned: when created from marketplace image
                    sample: 7.5.2018050901
                id:
                    description:
                        - Custom image resource ID.
                    type: str
                    returned: when created from custom image
                    sample: /subscriptions/xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx/resourceGroups/myResourceGroup/providers/Microsoft.Compute/images/myImage
                community_gallery_image_id:
                    description:
                        - The community gallery image unique id for vm deployment.
                    type: str
                    returned: when created from community gallery image
                    sample: "/CommunityGalleries/yellowbrick-fc7e81f1-87dd-4989-9ca8-03743762e873/Images/Ubuntu-5.15.0-1035-azure_22.04"
        location:
            description:
                - Resource location.
            returned: always
            type: str
            sample: japaneast
        maintenance_redeploy_status:
            description:
                - If maintenance is scheduled for this server set to something like example, otherwise empty dict
            returned: always
            type: dict
            sample: { "is_customer_initiated_maintenance_allowed": true, "last_operation_result_code": "None", "maintenance_window_end_time":
                    "2025-06-18T23:59:00.000Z", "maintenance_window_start_time": "2025-06-12T00:00:00.000Z", "pre_maintenance_window_end_time":
                    "2025-06-11T23:30:00.000Z", "pre_maintenance_window_start_time": "2025-01-30T00:00:00.000Z" }
        name:
            description:
                - Resource name.
            returned: always
            type: str
            sample: myVm
        network_interface_names:
            description:
                - List of attached network interfaces.
            returned: always
            type: list
            sample: [
                "myNetworkInterface"
            ]
        proximityPlacementGroup:
            description:
                - The name or ID of the proximity placement group the VM should be associated with.
            type: dict
            returned: always
            sample: { "id": "/subscriptions/xxx/resourceGroups/xxx/providers/Microsoft.Compute/proximityPlacementGroups/testid13"}
        CapacityReservation:
            description:
                - The name or ID of the capacity reservation group to be associated with.
            type: dict
            returned: always
            sample: { }
        os_disk_caching:
            description:
                - Type of OS disk caching.
            returned: always
            type: str
            sample: ReadOnly
        os_type:
            description:
                - Base type of operating system.
            returned: always
            type: str
            sample: Linux
        resource_group:
            description:
                - Resource group.
            returned: always
            type: str
            sample: myResourceGroup
        state:
            description:
                - State of the resource.
            returned: always
            type: str
            sample: present
        tags:
            description:
                - Resource tags.
            returned: always
            type: dict
            sample: { "key1":"value1" }
        vm_agent_version:
            description:
                - Version of the Azure VM Agent (waagent) running inside the VM.
            returned: always
            type: str
            sample: '2.9.1.1'
        vm_size:
            description:
                - Virtual machine size.
            returned: always
            type: str
            sample: Standard_D4
        zones:
            description:
                - A list of Availability Zones for your VM.
            type: list
            sample: [1]
        power_state:
            description:
                - Power state of the virtual machine.
            returned: always
            type: str
            sample: running
        display_status:
            description:
                - The short localizable label for the status.
            returned: always
            type: str
            sample: "VM running"
        provisioning_state:
            description:
                - The provisioning state, which only appears in the response.
            returned: always
            type: str
            sample: running
        identity:
            description:
                - The identity of the virtual machine.
            type: dict
            returned: always
            sample: {
                    "principal_id": "xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx",
                    "tenant_id": "xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx",
                    "type": "SystemAssigned, UserAssigned",
                    "user_assigned_identities": {
                        "/subscriptions/xxx/resourceGroups/testRG/providers/Microsoft.ManagedIdentity/userAssignedIdentities/test": {
                            "client_id": "xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx",
                            "principal_id": "xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx"
                        }
                    }
        }
        security_profile:
            description:
                - Specifies the Security related profile settings for the virtual machine.
            type: complex
            returned: when-used
            contains:
                encryption_at_host:
                    description:
                        - This property can be used by user in the request to enable or disable the Host Encryption for the virtual machine.
                        - This will enable the encryption for all the disks including Resource/Temp disk at host itself.
                    type: bool
                    returned: when-enabled
                    sample: True
                security_type:
                    description:
                        - Specifies the SecurityType of the virtual machine.
                        - It is set as TrustedLaunch to enable UefiSettings.
                    type: str
                    returned: when-enabled
                    sample: TrustedLaunch
                uefi_settings:
                    description:
                        - Specifies the security settings like secure boot and vTPM used while creating the virtual machine.
                    type: complex
                    returned: when-enabled
                    contains:
                        secure_boot_enabled:
                            description:
                                - Specifies whether secure boot should be enabled on the virtual machine.
                            type: bool
                            returned: when-enabled
                            sample: True
                        v_tpm_enabled:
                            description:
                                - Specifies whether vTPM should be enabled on the virtual machine.
                            type: bool
                            returned: when-enabled
                            sample: True
'''

try:
    from azure.mgmt.core.tools import parse_resource_id
    from azure.core.exceptions import ResourceNotFoundError
except Exception:
    # This is handled in azure_rm_common
    pass

from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common import AzureRMModuleBase
from ansible.module_utils.six.moves.urllib.parse import urlparse
import re


AZURE_OBJECT_CLASS = 'VirtualMachine'

AZURE_ENUM_MODULES = ['azure.mgmt.compute.models']


class AzureRMVirtualMachineInfo(AzureRMModuleBase):

    def __init__(self):

        self.module_arg_spec = dict(
            resource_group=dict(type='str'),
            name=dict(type='str'),
            tags=dict(type='list', elements='str')
        )

        self.results = dict(
            changed=False,
            vms=[]
        )

        self.resource_group = None
        self.name = None
        self.tags = None

        super(AzureRMVirtualMachineInfo, self).__init__(self.module_arg_spec,
                                                        supports_check_mode=True,
                                                        supports_tags=False,
                                                        facts_module=True)

    def exec_module(self, **kwargs):

        for key in self.module_arg_spec:
            setattr(self, key, kwargs[key])

        if self.name and not self.resource_group:
            self.fail("Parameter error: resource group required when filtering by name.")
        if self.name:
            self.results['vms'] = self.get_item()
        elif self.resource_group:
            self.results['vms'] = self.list_items_by_resourcegroup()
        else:
            self.results['vms'] = self.list_all_items()

        return self.results

    def get_item(self):
        self.log('Get properties for {0}'.format(self.name))
        item = None
        result = []

        item = self.get_vm(self.resource_group, self.name)

        if item and self.has_tags(item.get('tags'), self.tags):
            result = [item]

        return result

    def list_items_by_resourcegroup(self):
        self.log('List all items')
        try:
            items = self.compute_client.virtual_machines.list(self.resource_group)
        except ResourceNotFoundError as exc:
            self.fail("Failed to list all items - {0}".format(str(exc)))

        results = []
        for item in items:
            if self.has_tags(item.tags, self.tags):
                results.append(self.get_vm(self.resource_group, item.name))
        return results

    def list_all_items(self):
        self.log('List all items')
        try:
            items = self.compute_client.virtual_machines.list_all()
        except ResourceNotFoundError as exc:
            self.fail("Failed to list all items - {0}".format(str(exc)))

        results = []
        for item in items:
            if self.has_tags(item.tags, self.tags):
                results.append(self.get_vm(parse_resource_id(item.id).get('resource_group'), item.name))
        return results

    def get_vm(self, resource_group, name):
        '''
        Get the VM with expanded instanceView

        :return: VirtualMachine object
        '''
        try:
            vm = self.compute_client.virtual_machines.get(resource_group, name, expand='instanceview')
            return self.serialize_vm(vm)
        except ResourceNotFoundError as exc:
            self.fail("Error getting virtual machine {0} - {1}".format(self.name, str(exc)))

    def serialize_vm(self, vm):
        '''
        Convert a VirtualMachine object to dict.

        :param vm: VirtualMachine object
        :return: dict
        '''

        result = self.serialize_obj(vm, AZURE_OBJECT_CLASS, enum_modules=AZURE_ENUM_MODULES)
        resource_group = parse_resource_id(result['id']).get('resource_group')
        instance = None
        power_state = None
        display_status = None

        try:
            instance = self.compute_client.virtual_machines.instance_view(resource_group, vm.name)
            instance = self.serialize_obj(instance, AZURE_OBJECT_CLASS, enum_modules=AZURE_ENUM_MODULES)
        except Exception as exc:
            self.fail("Error getting virtual machine {0} instance view - {1}".format(vm.name, str(exc)))

        for index in range(len(instance['statuses'])):
            code = instance['statuses'][index]['code'].split('/')
            if code[0] == 'PowerState':
                power_state = code[1]
                display_status = instance['statuses'][index]['display_status']
            elif code[0] == 'OSState' and code[1] == 'generalized':
                display_status = instance['statuses'][index]['display_status']
                power_state = 'generalized'
                break
            elif code[0] == 'ProvisioningState' and code[1] == 'failed':
                display_status = instance['statuses'][index]['display_status']
                power_state = ''
                break

        new_result = {}

        if instance.get('maintenance_redeploy_status') is not None:
            new_result['maintenance_redeploy_status'] = instance['maintenance_redeploy_status']
        else:
            new_result['maintenance_redeploy_status'] = dict()

        if instance.get('vm_agent') is not None:
            new_result['vm_agent_version'] = instance['vm_agent'].get('vm_agent_version')
        else:
            new_result['vm_agent_version'] = 'Unknown'

        if vm.security_profile is not None:
            new_result['security_profile'] = dict()
            if vm.security_profile.encryption_at_host is not None:
                new_result['security_profile']['encryption_at_host'] = vm.security_profile.encryption_at_host
            if vm.security_profile.security_type is not None:
                new_result['security_profile']['security_type'] = vm.security_profile.security_type
            if vm.security_profile.uefi_settings is not None:
                new_result['security_profile']['uefi_settings'] = dict()
                if vm.security_profile.uefi_settings.secure_boot_enabled is not None:
                    new_result['security_profile']['uefi_settings']['secure_boot_enabled'] = vm.security_profile.uefi_settings.secure_boot_enabled
                if vm.security_profile.uefi_settings.v_tpm_enabled is not None:
                    new_result['security_profile']['uefi_settings']['v_tpm_enabled'] = vm.security_profile.uefi_settings.v_tpm_enabled

        new_result['power_state'] = power_state
        new_result['display_status'] = display_status
        new_result['provisioning_state'] = vm.provisioning_state
        new_result['id'] = vm.id
        new_result['resource_group'] = resource_group
        new_result['name'] = vm.name
        new_result['state'] = 'present'
        new_result['location'] = vm.location
        new_result['vm_size'] = result['hardware_profile']['vm_size']
        new_result['user_data'] = result.get('user_data', None)

        new_result['proximityPlacementGroup'] = result.get('proximity_placement_group')
        new_result['zones'] = result.get('zones', None)
        new_result['additional_capabilities'] = result.get('additional_capabilities')
        new_result['identity'] = result.get('identity')
        new_result['capacity_reservation'] = dict()
        if result.get('capacity_reservation') is not None:
            new_result['capacity_reservation']['capacity_reservation_group'] = result.get('capacity_reservation', {}).get('capacity_reservation_group')
        os_profile = result.get('os_profile')
        if os_profile is not None:
            new_result['admin_username'] = os_profile.get('admin_username')
        image = result['storage_profile'].get('image_reference')
        if image is not None:
            if image.get('publisher', None) is not None:
                new_result['image'] = {
                    'publisher': image['publisher'],
                    'sku': image['sku'],
                    'offer': image['offer'],
                    'version': image['version']
                }
            elif image.get('community_gallery_image_id') is not None:
                new_result['image'] = {
                    'community_gallery_image_id': image.get('community_gallery_image_id')
                }
            else:
                new_result['image'] = {
                    'id': image.get('id', None)
                }

        new_result['boot_diagnostics'] = {
            'enabled': 'diagnostics_profile' in result and
                       'boot_diagnostics' in result['diagnostics_profile'] and
                       result['diagnostics_profile']['boot_diagnostics']['enabled'] or False,
            'storage_uri': 'diagnostics_profile' in result and
                           'boot_diagnostics' in result['diagnostics_profile'] and
                           result['diagnostics_profile']['boot_diagnostics'].get('storageUri', None)
        }
        if new_result['boot_diagnostics']['enabled']:
            new_result['boot_diagnostics']['console_screenshot_uri'] = result['instance_view']['boot_diagnostics'].get('console_screenshot_blob_uri')
            new_result['boot_diagnostics']['serial_console_log_uri'] = result['instance_view']['boot_diagnostics'].get('serial_console_log_blob_uri')

        vhd = result['storage_profile']['os_disk'].get('vhd')
        if vhd is not None:
            url = urlparse(vhd['uri'])
            new_result['storage_account_name'] = url.netloc.split('.')[0]
            new_result['storage_container_name'] = url.path.split('/')[1]
            new_result['storage_blob_name'] = url.path.split('/')[-1]

        new_result['os_disk'] = result['storage_profile']['os_disk']
        new_result['os_disk_caching'] = result['storage_profile']['os_disk']['caching']
        new_result['os_type'] = result['storage_profile']['os_disk']['os_type']
        new_result['data_disks'] = []
        disks = result['storage_profile']['data_disks']
        for disk_index in range(len(disks)):
            new_result['data_disks'].append({
                'lun': disks[disk_index].get('lun'),
                'name': disks[disk_index].get('name'),
                'disk_size_gb': disks[disk_index].get('disk_size_gb'),
                'managed_disk_type': disks[disk_index].get('managed_disk', {}).get('storage_account_type'),
                'managed_disk_id': disks[disk_index].get('managed_disk', {}).get('id'),
                'caching': disks[disk_index].get('caching'),
                'write_accelerator_enabled': disks[disk_index].get('write_accelerator_enabled', False)
            })

        new_result['network_interface_names'] = []
        nics = result['network_profile']['network_interfaces']
        for nic_index in range(len(nics)):
            new_result['network_interface_names'].append(re.sub('.*networkInterfaces/', '', nics[nic_index]['id']))

        new_result['tags'] = vm.tags
        return new_result


def main():
    AzureRMVirtualMachineInfo()


if __name__ == '__main__':
    main()



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: icap_settings_configuration_models
short_description: Resource module for Icap Settings Configuration Models
description:
  - Manage operation create of the resource Icap Settings Configuration Models.
  - This creates an ICAP configuration intent for preview approval.
  - The intent is not deployed to the device until further preview-approve APIs are applied.
  - This API is the first step in the preview-approve workflow, which consists of several APIs.
  - Skipping any API in the process is not recommended for a complete preview-approve use case.
  - For detailed information about the usage of the API, please refer to the Open API specification document
    https //github.com/cisco-en-programmability/catalyst-center-api-specs/blob/main/Assurance/
    CE_Cat_Center_Org-ICAP_APIs-1.0.0-resolved.yaml.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  payload:
    description: Icap Settings Configuration Models's payload.
    elements: dict
    suboptions:
      apId:
        description: Ap Id.
        type: str
      captureType:
        description: Capture Type.
        type: str
      clientMac:
        description: Client Mac.
        type: str
      durationInMins:
        description: Duration In Mins.
        type: int
      otaBand:
        description: Ota Band.
        type: str
      otaChannel:
        description: Ota Channel.
        type: int
      otaChannelWidth:
        description: Ota Channel Width.
        type: int
      slot:
        description: Slot.
        elements: float
        type: list
      wlcId:
        description: Wlc Id.
        type: str
    type: list
  previewDescription:
    description: PreviewDescription query parameter. The ICAP intent's preview-deploy description string.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Sensors CreatesAnICAPConfigurationIntentForPreviewApprove
    description: Complete reference of the CreatesAnICAPConfigurationIntentForPreviewApprove API.
    link: https://developer.cisco.com/docs/dna-center/#!creates-an-icap-configuration-intent-for-preview-approve
notes:
  - SDK Method used are
    sensors.Sensors.creates_an_i_cap_configuration_intent_for_preview_approve,
  - Paths used are
    post /dna/intent/api/v1/icapSettings/configurationModels,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.icap_settings_configuration_models:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    payload:
      - apId: string
        captureType: string
        clientMac: string
        durationInMins: 0
        otaBand: string
        otaChannel: 0
        otaChannelWidth: 0
        slot:
          - 0
        wlcId: string
    previewDescription: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: access_groups_info
short_description: Information module for Access Groups
description:
  - Get all Access Groups.
  - Get Access Groups by id.
  - Get all access groups in the system.
  - Get an access group in the system.
version_added: '6.46.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  userCount:
    description:
      - >
        UserCount query parameter. If set to true, it will return number of users associated with each access
        group. Default is false.
    type: str
  names:
    description:
      - >
        Names query parameter. Get access groups by passing comma separated list of names. It performs an exact
        character match.
    type: str
  type:
    description:
      - Type query parameter. Get access groups by passing the type of the resource such as site.
    type: str
  sourceResourceIds:
    description:
      - >
        SourceResourceIds query parameter. Get access groups by passing the ids of the resource associated with
        it such as the site hierarchy id.
    type: str
  ids:
    description:
      - Ids query parameter. Get access groups by passing a comma separated list of their ids.
    type: str
  offset:
    description:
      - Offset query parameter. An integer representing the starting access group in the page returned.
    type: int
  limit:
    description:
      - Limit query parameter. Limit on the number of access groups on a page. Default page size is 20.
    type: int
  id:
    description:
      - Id path parameter. Id of the access group to query.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for User and Roles GetAccessGroup
    description: Complete reference of the GetAccessGroup API.
    link: https://developer.cisco.com/docs/dna-center/#!get-access-group
  - name: Cisco DNA Center documentation for User and Roles GetAccessGroups
    description: Complete reference of the GetAccessGroups API.
    link: https://developer.cisco.com/docs/dna-center/#!get-access-groups
notes:
  - SDK Method used are
    userand_roles.UserandRoles.get_access_group,
    userand_roles.UserandRoles.get_access_groups,
  - Paths used are
    get /dna/system/api/v1/accessGroups,
    get /dna/system/api/v1/accessGroups/{id},
"""

EXAMPLES = r"""
---
- name: Get all Access Groups
  cisco.dnac.access_groups_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    userCount: string
    names: string
    type: string
    sourceResourceIds: string
    ids: string
    offset: 0
    limit: 0
  register: result
- name: Get Access Groups by id
  cisco.dnac.access_groups_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "id": "string",
      "accessGroupInfo": {
        "name": "string",
        "description": "string",
        "resourceGroups": [
          {
            "name": "string",
            "srcResourceId": "string",
            "type": "string"
          }
        ],
        "role": [
          "string"
        ]
      },
      "meta": {
        "created": "string",
        "createdBy": "string",
        "lastModified": "string",
        "lastModifiedBy": "string"
      }
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_device_images_info
short_description: Information module for Network Device Images
description:
  - Get all Network Device Images.
  - Get Network Device Images by id. - > The API retrieves information about running images and golden image bundle, if they
    are available for the network device. It also provides network device update status and image update status related to
    the golden image bundle and the compatible features supported by the network device. Network device with `networkDeviceImageStatus`
    set as `OUTDATED` is considered ready for update based on the golden image bundle. - > This API retrieves information
    about running images and golden image bundle, if they are available for network devices. It also provides network device
    update status and image update status related to the golden image bundle and the compatible features supported by the
    network devices.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  managementAddress:
    description:
      - ManagementAddress query parameter. IP address or DNS name used to access and manage network devices.
    type: str
  networkDeviceImageStatus:
    description:
      - >
        NetworkDeviceImageStatus query parameter. Network device image status with respect to golden images.
        Available values OUTDATED, UP_TO_DATE, UNKNOWN, CONFLICTED, UNSUPPORTED.
    type: str
  networkDeviceUpdateStatus:
    description:
      - >
        NetworkDeviceUpdateStatus query parameter. Network device current update status with respect to golden
        images. Available values DISTRIBUTION_PENDING, DISTRIBUTION_IN_PROGRESS, DISTRIBUTION_FAILED,
        ACTIVATION_PENDING, ACTIVATION_IN_PROGRESS, ACTIVATION_FAILED, DEVICE_UP_TO_DATE,UNKNOWN.
    type: str
  sortBy:
    description:
      - >
        SortBy query parameter. Sort the response by a specified attribute. Available attributes for sorting are
        `id`,`networkDeviceUpdateStatus`,`networkDeviceImageStatus`, `goldenImages.name`,
        `goldenImages.version`, `installedImages.name`, `installedImages.version`.
    type: str
  order:
    description:
      - >
        Order query parameter. Whether ascending or descending order should be used to sort the response.
        Available values asc, desc.
    type: str
  offset:
    description:
      - >
        Offset query parameter. The first record to show for this page; the first record is numbered 1. The
        minimum value is 1.
    type: int
  limit:
    description:
      - >
        Limit query parameter. The number of records to show for this page. The minimum and maximum values are 1
        and 500, respectively.
    type: int
  id:
    description:
      - Id path parameter. Network device identifier.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Software Image Management (SWIM) FetchNetworkDeviceWithImageDetails
    description: Complete reference of the FetchNetworkDeviceWithImageDetails API.
    link: https://developer.cisco.com/docs/dna-center/#!fetch-network-device-with-image-details
  - name: Cisco DNA Center documentation for Software Image Management (SWIM) GetTheListOfNetworkDevicesWithImageDetails
    description: Complete reference of the GetTheListOfNetworkDevicesWithImageDetails API.
    link: https://developer.cisco.com/docs/dna-center/#!get-the-list-of-network-devices-with-image-details
notes:
  - SDK Method used are
    software_image_management_swim.SoftwareImageManagementSwim.fetch_network_device_with_image_details,
    software_image_management_swim.SoftwareImageManagementSwim.get_the_list_of_network_devices_with_image_details,
  - Paths used are
    get /dna/intent/api/v1/networkDeviceImages,
    get /dna/intent/api/v1/networkDeviceImages/{id},
"""

EXAMPLES = r"""
---
- name: Get all Network Device Images
  cisco.dnac.network_device_images_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    managementAddress: string
    networkDeviceImageStatus: string
    networkDeviceUpdateStatus: string
    sortBy: string
    order: string
    offset: 0
    limit: 0
  register: result
- name: Get Network Device Images by id
  cisco.dnac.network_device_images_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "id": "string",
          "managementAddress": "string",
          "networkDevice": {
            "id": "string",
            "productNameOrdinal": 0,
            "productName": "string",
            "supervisorProductName": "string",
            "supervisorProductNameOrdinal": 0
          },
          "networkDeviceImageStatus": "string",
          "networkDeviceUpdateStatus": "string",
          "goldenImages": [
            {
              "id": "string",
              "name": "string",
              "version": "string",
              "imageType": "string",
              "goldenTaggingDetails": {
                "deviceRoles": "string",
                "deviceTags": "string",
                "siteId": "string",
                "siteName": "string",
                "isInherited": true
              }
            }
          ],
          "installedImages": [
            {
              "id": "string",
              "name": "string",
              "version": "string",
              "imageType": "string"
            }
          ],
          "compatibleFeatures": [
            {
              "key": "string",
              "value": "string"
            }
          ]
        }
      ],
      "version": "string"
    }
"""
